@@ -1,6 +1,6 @@
 /*
  * 32.newehdr.c - implementation of the elf{32,64}_newehdr(3) functions.
- * Copyright (C) 1995 - 2004 Michael Riepe
+ * Copyright (C) 1995 - 2006 Michael Riepe
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,13 +14,13 @@
  * 
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <private.h>
 
 #ifndef lint
-static const char rcsid[] = "@(#) $Id: 32.newehdr.c,v 1.13 2005/05/21 15:39:19 michael Exp $";
+static const char rcsid[] = "@(#) $Id: 32.newehdr.c,v 1.16 2008/05/23 08:15:34 michael Exp $";
 #endif /* lint */
 
 static char*
@@ -74,10 +74,7 @@ gelf_newehdr(Elf *elf, int cls) {
 	seterr(ERROR_UNKNOWN_CLASS);
 	return 0;
     }
-    if (!_elf_newehdr(elf, cls)) {
-	return 0;
-    }
-    return 1;	/* really? */
+    return (unsigned long)_elf_newehdr(elf, cls);
 }
 
 #endif /* __LIBELF64 */
