@@ -1,28 +1,28 @@
 /*
-gelfehdr.c - gelf_* translation functions.
-Copyright (C) 2000 - 2001 Michael Riepe
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
+ * gelfehdr.c - gelf_* translation functions.
+ * Copyright (C) 2000 - 2006 Michael Riepe
+ * 
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <private.h>
 
 #if __LIBELF64
 
 #ifndef lint
-static const char rcsid[] = "@(#) $Id: gelfehdr.c,v 1.6 2005/05/21 15:39:22 michael Exp $";
+static const char rcsid[] = "@(#) $Id: gelfehdr.c,v 1.9 2008/05/23 08:15:34 michael Exp $";
 #endif /* lint */
 
 #define check_and_copy(type, d, s, name, eret)		\
@@ -72,12 +72,13 @@ gelf_getehdr(Elf *elf, GElf_Ehdr *dst) {
 	check_and_copy(GElf_Half, dst, src, e_shnum,     NULL);
 	check_and_copy(GElf_Half, dst, src, e_shstrndx,  NULL);
     }
-    else if (valid_class(elf->e_class)) {
-	seterr(ERROR_UNIMPLEMENTED);
-	return NULL;
-    }
     else {
-	seterr(ERROR_UNKNOWN_CLASS);
+	if (valid_class(elf->e_class)) {
+	    seterr(ERROR_UNIMPLEMENTED);
+	}
+	else {
+	    seterr(ERROR_UNKNOWN_CLASS);
+	}
 	return NULL;
     }
     if (dst == &buf) {
@@ -124,12 +125,13 @@ gelf_update_ehdr(Elf *elf, GElf_Ehdr *src) {
 	check_and_copy(Elf32_Half, dst, src, e_shnum,     0);
 	check_and_copy(Elf32_Half, dst, src, e_shstrndx,  0);
     }
-    else if (valid_class(elf->e_class)) {
-	seterr(ERROR_UNIMPLEMENTED);
-	return 0;
-    }
     else {
-	seterr(ERROR_UNKNOWN_CLASS);
+	if (valid_class(elf->e_class)) {
+	    seterr(ERROR_UNIMPLEMENTED);
+	}
+	else {
+	    seterr(ERROR_UNKNOWN_CLASS);
+	}
 	return 0;
     }
     return 1;
