@@ -1,28 +1,28 @@
 /*
-gelfshdr.c - gelf_* translation functions.
-Copyright (C) 2000 - 2001 Michael Riepe
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
+ * gelfshdr.c - gelf_* translation functions.
+ * Copyright (C) 2000 - 2006 Michael Riepe
+ * 
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <private.h>
 
 #if __LIBELF64
 
 #ifndef lint
-static const char rcsid[] = "@(#) $Id: gelfshdr.c,v 1.7 2005/05/21 15:39:22 michael Exp $";
+static const char rcsid[] = "@(#) $Id: gelfshdr.c,v 1.10 2008/05/23 08:15:34 michael Exp $";
 #endif /* lint */
 
 #define check_and_copy(type, d, s, name, eret)		\
@@ -65,12 +65,13 @@ gelf_getshdr(Elf_Scn *scn, GElf_Shdr *dst) {
 	check_and_copy(GElf_Xword, dst, src, sh_addralign, NULL);
 	check_and_copy(GElf_Xword, dst, src, sh_entsize,   NULL);
     }
-    else if (valid_class(scn->s_elf->e_class)) {
-	seterr(ERROR_UNIMPLEMENTED);
-	return NULL;
-    }
     else {
-	seterr(ERROR_UNKNOWN_CLASS);
+	if (valid_class(scn->s_elf->e_class)) {
+	    seterr(ERROR_UNIMPLEMENTED);
+	}
+	else {
+	    seterr(ERROR_UNKNOWN_CLASS);
+	}
 	return NULL;
     }
     if (dst == &buf) {
@@ -109,12 +110,13 @@ gelf_update_shdr(Elf_Scn *scn, GElf_Shdr *src) {
 	check_and_copy(Elf32_Word, dst, src, sh_addralign, 0);
 	check_and_copy(Elf32_Word, dst, src, sh_entsize,   0);
     }
-    else if (valid_class(scn->s_elf->e_class)) {
-	seterr(ERROR_UNIMPLEMENTED);
-	return 0;
-    }
     else {
-	seterr(ERROR_UNKNOWN_CLASS);
+	if (valid_class(scn->s_elf->e_class)) {
+	    seterr(ERROR_UNIMPLEMENTED);
+	}
+	else {
+	    seterr(ERROR_UNKNOWN_CLASS);
+	}
 	return 0;
     }
     return 1;
