@@ -14,23 +14,23 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <private.h>
 #include <nlist.h>
 
 #ifndef lint
-static const char rcsid[] = "@(#) $Id: nlist.c,v 1.13 2005/05/21 15:39:25 michael Exp $";
+static const char rcsid[] = "@(#) $Id: nlist.c,v 1.15 2008/05/23 08:15:35 michael Exp $";
 #endif /* lint */
 
+#if !defined(_WIN32)
 #if HAVE_FCNTL_H
 #include <fcntl.h>
-#endif /* HAVE_FCNTL_H */
-
-#if !HAVE_FCNTL_H || defined(_WIN32)	/* W32 seems to lack `open()' in <fcntl.h> */
+#else
 extern int open();
-#endif /* !HAVE_FCNTL_H || defined(_WIN32) */
+#endif /* HAVE_FCNTL_H */
+#endif /* defined(_WIN32) */
 
 #ifndef O_RDONLY
 #define O_RDONLY	0
